@@ -1,24 +1,22 @@
-#include "config.h"
+/* Copyright (c) 2000, Len Budney. See COPYING for details. */
+
 #include "stat_dir.h"
+#include "strerr.h"
 #include <sys/stat.h>
 #include <unistd.h>
-#include <stdio.h>
 
 /* ****************************************************************** */
 void stat_dir(char *dirname) {
   struct stat filestat;
 
   if(stat(dirname,&filestat) != 0) {
-    fprintf(stderr, "Could not stat directory %s.\n",dirname);
-    exit(1);
+    strerr_die2sys(111,"safecat: fatal: ","could not stat directory ");
   }
   if( !S_ISDIR(filestat.st_mode) ) {
-    fprintf(stderr, "%s is not a directory.\n",dirname);
-    exit(1);
+    strerr_die2x(111, "safecat: fatal: ","not a directory");
   }
   if((filestat.st_mode & S_IWUSR) != S_IWUSR) {
-    fprintf(stderr, "%s is not writable.\n",dirname);
-    exit(1);
+    strerr_die2x(111, "safecat: fatal: ","directory not writable");
   }
   filestat.st_mode = 0;
 }
